==> google-cloud-sdk-413.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/googlecloudsdk/generated_clients/gapic_clients/spanner_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.spanner import SpannerClient
from .services.spanner import SpannerAsyncClient

from .types.commit_response import CommitResponse
from .types.keys import KeyRange
from .types.keys import KeySet
from .types.mutation import Mutation
from .types.query_plan import PlanNode
from .types.query_plan import QueryPlan
from .types.result_set import PartialResultSet
from .types.result_set import ResultSet
from .types.result_set import ResultSetMetadata
from .types.result_set import ResultSetStats
from .types.spanner import BatchCreateSessionsRequest
from .types.spanner import BatchCreateSessionsResponse
from .types.spanner import BeginTransactionRequest
from .types.spanner import CommitRequest
from .types.spanner import CreateSessionRequest
from .types.spanner import DeleteSessionRequest
from .types.spanner import ExecuteBatchDmlRequest
from .types.spanner import ExecuteBatchDmlResponse
from .types.spanner import ExecuteSqlRequest
from .types.spanner import GetSessionRequest
from .types.spanner import ListSessionsRequest
from .types.spanner import ListSessionsResponse
from .types.spanner import Partition
from .types.spanner import PartitionOptions
from .types.spanner import PartitionQueryRequest
from .types.spanner import PartitionReadRequest
from .types.spanner import PartitionResponse
from .types.spanner import ReadRequest
from .types.spanner import RequestOptions
from .types.spanner import RollbackRequest
from .types.spanner import Session
from .types.transaction import Transaction
from .types.transaction import TransactionOptions
from .types.transaction import TransactionSelector
from .types.type import StructType
from .types.type import Type
from .types.type import TypeAnnotationCode
from .types.type import TypeCode

__all__ = (
    'SpannerAsyncClient',
'BatchCreateSessionsRequest',
'BatchCreateSessionsResponse',
'BeginTransactionRequest',
'CommitRequest',
'CommitResponse',
'CreateSessionRequest',
'DeleteSessionRequest',
'ExecuteBatchDmlRequest',
'ExecuteBatchDmlResponse',
'ExecuteSqlRequest',
'GetSessionRequest',
'KeyRange',
'KeySet',
'ListSessionsRequest',
'ListSessionsResponse',
'Mutation',
'PartialResultSet',
'Partition',
'PartitionOptions',
'PartitionQueryRequest',
'PartitionReadRequest',
'PartitionResponse',
'PlanNode',
'QueryPlan',
'ReadRequest',
'RequestOptions',
'ResultSet',
'ResultSetMetadata',
'ResultSetStats',
'RollbackRequest',
'Session',
'SpannerClient',
'StructType',
'Transaction',
'TransactionOptions',
'TransactionSelector',
'Type',
'TypeAnnotationCode',
'TypeCode',
)

==> google-cloud-sdk-438.0.0-darwin-x86_64.tar.gz: google-cloud-sdk/lib/googlecloudsdk/generated_clients/gapic_clients/spanner_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from googlecloudsdk.generated_clients.gapic_clients.spanner_v1 import gapic_version as package_version

__version__ = package_version.__version__


from .services.spanner import SpannerClient
from .services.spanner import SpannerAsyncClient

from .types.commit_response import CommitResponse
from .types.keys import KeyRange
from .types.keys import KeySet
from .types.mutation import Mutation
from .types.query_plan import PlanNode
from .types.query_plan import QueryPlan
from .types.result_set import PartialResultSet
from .types.result_set import ResultSet
from .types.result_set import ResultSetMetadata
from .types.result_set import ResultSetStats
from .types.spanner import BatchCreateSessionsRequest
from .types.spanner import BatchCreateSessionsResponse
from .types.spanner import BeginTransactionRequest
from .types.spanner import CommitRequest
from .types.spanner import CreateSessionRequest
from .types.spanner import DeleteSessionRequest
from .types.spanner import ExecuteBatchDmlRequest
from .types.spanner import ExecuteBatchDmlResponse
from .types.spanner import ExecuteSqlRequest
from .types.spanner import GetSessionRequest
from .types.spanner import ListSessionsRequest
from .types.spanner import ListSessionsResponse
from .types.spanner import Partition
from .types.spanner import PartitionOptions
from .types.spanner import PartitionQueryRequest
from .types.spanner import PartitionReadRequest
from .types.spanner import PartitionResponse
from .types.spanner import ReadRequest
from .types.spanner import RequestOptions
from .types.spanner import RollbackRequest
from .types.spanner import Session
from .types.transaction import Transaction
from .types.transaction import TransactionOptions
from .types.transaction import TransactionSelector
from .types.type import StructType
from .types.type import Type
from .types.type import TypeAnnotationCode
from .types.type import TypeCode

__all__ = (
    'SpannerAsyncClient',
'BatchCreateSessionsRequest',
'BatchCreateSessionsResponse',
'BeginTransactionRequest',
'CommitRequest',
'CommitResponse',
'CreateSessionRequest',
'DeleteSessionRequest',
'ExecuteBatchDmlRequest',
'ExecuteBatchDmlResponse',
'ExecuteSqlRequest',
'GetSessionRequest',
'KeyRange',
'KeySet',
'ListSessionsRequest',
'ListSessionsResponse',
'Mutation',
'PartialResultSet',
'Partition',
'PartitionOptions',
'PartitionQueryRequest',
'PartitionReadRequest',
'PartitionResponse',
'PlanNode',
'QueryPlan',
'ReadRequest',
'RequestOptions',
'ResultSet',
'ResultSetMetadata',
'ResultSetStats',
'RollbackRequest',
'Session',
'SpannerClient',
'StructType',
'Transaction',
'TransactionOptions',
'TransactionSelector',
'Type',
'TypeAnnotationCode',
'TypeCode',
)
